@@ -335,13 +335,13 @@ def delete_department_user_map(organization_id: int, department_id: int, user_id
 
     dic = {f"path__0_{len(path)}": path, "organization_id": organization_id}
 
-    departments = Department.objects.filter(**dic).values_list("id", flat=True)
+    departments = list(Department.objects.filter(**dic).values_list("id", flat=True))
 
     departments.append(department_instance.id)
 
     DepartmentUserMap.objects.filter(
         department__organization_id=organization_id,
-        department_id__in=department_id,
+        department_id__in=departments,
         user_id__in=user_ids
     ).delete()
 
